changeset 69547:eb2730e56d3b

(Fw32_select_font): Doc fix.
author Eli Zaretskii <eliz@gnu.org>
date Sat, 18 Mar 2006 13:29:34 +0000
parents fa6cedf25a5b
children 83eb46979fc7
files src/w32fns.c
diffstat 1 files changed, 6 insertions(+), 2 deletions(-) [+]
line wrap: on
line diff
--- a/src/w32fns.c	Sat Mar 18 13:13:30 2006 +0000
+++ b/src/w32fns.c	Sat Mar 18 13:29:34 2006 +0000
@@ -7937,8 +7937,12 @@
  ***********************************************************************/
 
 DEFUN ("w32-select-font", Fw32_select_font, Sw32_select_font, 0, 2, 0,
-       doc: /* Select a font using the W32 font dialog.
-Returns an X font string corresponding to the selection.  */)
+       doc: /* Select a font for the named FRAME using the W32 font dialog.
+Returns an X-style font string corresponding to the selection.
+
+If FRAME is omitted or nil, it defaults to the selected frame.
+If INCLUDE-PROPORTIONAL is non-nil, include proportional fonts
+in the font selection dialog. */)
   (frame, include_proportional)
      Lisp_Object frame, include_proportional;
 {